==> kazana-bootstrap-2.1.1.tgz: package/README.md <==
# kazana-bootstrap

> Kazana core module to bootstrap all things CouchDB

[![NPM version](https://badge.fury.io/js/kazana-bootstrap.svg)](https://www.npmjs.com/package/kazana-bootstrap)
[![Build Status](https://travis-ci.org/eHealthAfrica/kazana-bootstrap.svg?branch=master)](https://travis-ci.org/eHealthAfrica/kazana-bootstrap)

## Usage

```
var bootstrap = require('kazana-bootstrap')

var options = {
  bootstrapPath: path.resolve(__dirname, '../bootstrap'),
  config: { // appConfig as returned by kazana-config
    admin: {
      username: 'admin',
      password: 'secret'
    }
  },
  couchUrl: 'http://localhost:5984'
};

bootstrap(options, function (error) {});
```

## Here is what happens

`kazana-bootstrap` walks trough the `/templates/bootstrap` and
`/templates/migrations` folders,
and uses its files folders as input to bootstrap the CouchDB database at
`MNUTRITION_COUCHDB_URL`.

It currently does these things:

1. sets (and overrides) _config
2. creates databases (unless existent)
3. sets (and overrides) database `_security` settings
4. creates and updates test user accounts
5. creates and updates design documents

## Test

[![Dependency Status](https://david-dm.org/eHealthAfrica/kazana-bootstrap.svg)](https://david-dm.org/eHealthAfrica/kazana-bootstrap)
[![devDependency Status](https://david-dm.org/eHealthAfrica/kazana-bootstrap/dev-status.svg)](https://david-dm.org/eHealthAfrica/kazana-bootstrap#info=devDependencies)

```
npm test
```

## Credit

Brought to you by [eHealth Africa](http://ehealthafrica.org/)
— good tech for hard places.

## License

[Apache-2.0](http://www.apache.org/licenses/LICENSE-2.0)

==> kazana-bootstrap-2.1.2.tgz: package/README.md <==
# kazana-bootstrap

> Kazana core module to bootstrap all things CouchDB

[![NPM version](https://badge.fury.io/js/kazana-bootstrap.svg)](https://www.npmjs.com/package/kazana-bootstrap)
[![Build Status](https://travis-ci.org/eHealthAfrica/kazana-bootstrap.svg?branch=master)](https://travis-ci.org/eHealthAfrica/kazana-bootstrap)

## Usage

```
var bootstrap = require('kazana-bootstrap')

var options = {
  name: 'my-app',
  config: { // appConfig as returned by kazana-config
    admin: {
      username: 'admin',
      password: 'secret'
    }
  },
  couchUrl: 'http://localhost:5984',
  bootstrapPath: path.resolve(__dirname, '../bootstrap')
};

bootstrap(options, function (error) {});
```

## Here is what happens

`kazana-bootstrap` does two things:
* creates admin user if couch is in admin party
* bootstraps CouchDB from [couchdb-bootstrap](https://github.com/eHealthAfrica/couchdb-bootstrap) folder

The following tasks can be performed with CouchDB Bootstrap:

* set and override `/_config`
* create databases (unless existent)
* create and update database \_security objects
* create and update user accounts
* create and update design documents
* create and update replication documents
* create and update seed documents

## Test

[![Dependency Status](https://david-dm.org/eHealthAfrica/kazana-bootstrap.svg)](https://david-dm.org/eHealthAfrica/kazana-bootstrap)
[![devDependency Status](https://david-dm.org/eHealthAfrica/kazana-bootstrap/dev-status.svg)](https://david-dm.org/eHealthAfrica/kazana-bootstrap#info=devDependencies)

```
npm test
```

## Credit

Brought to you by [eHealth Africa](http://ehealthafrica.org/)
— good tech for hard places.

## License

[Apache-2.0](http://www.apache.org/licenses/LICENSE-2.0)
